@@ -29,7 +29,8 @@ click.echo(json.dumps(rv))
 
 ALLOWED_IMPORTS = set([
     'weakref', 'os', 'struct', 'collections', 'sys', 'contextlib',
-    'functools', 'stat', 're', 'codecs', 'inspect', 'itertools', 'io'
+    'functools', 'stat', 're', 'codecs', 'inspect', 'itertools', 'io',
+    'threading'
 ])
 
 
